@@ -35,6 +35,7 @@ import socket
 import sys
 import hashlib
 import random
+from urlparse import urlparse
 
 from cStringIO import StringIO
 #from couchdbcurl import json
@@ -404,7 +405,7 @@ class Database(object):
         :return: the ID of the created document
         :rtype: `unicode`
         """
-        data = self.resource.post(content=data)
+        data = self.resource.post(content=data, headers={'Content-Type': 'application/json'})
         return data['id']
 
     def compact(self):
@@ -622,7 +623,7 @@ class Database(object):
 
         data = self.resource(doc['_id']).put(filename, content=content,
                                                    headers={
-            'Content-Type': content_type
+            'Content-Type': str(content_type)
         }, rev=doc['_rev'])
         doc['_rev'] = data['rev']
 
@@ -880,7 +881,7 @@ class Document(dict):
         if db:
             rand = ''
             if force_random_suffix:
-                rand = hashlib.sha1(str(random.random())).hexdigest()[:suffix_length]
+                rand = '_' + hashlib.sha1(str(random.random())).hexdigest()[:suffix_length]
                 
             doc_id = id_string % (id, rand)
             
@@ -1090,7 +1091,7 @@ class ViewResults(object):
 
     def _fetch(self):
         data = self.view._exec(self.options)
-        self._rows = [Row(row) for row in data['rows']]
+        self._rows = [Row(row) for row in data['rows'] if not row['error']]
         self._total_rows = data.get('total_rows')
         self._offset = data.get('offset', 0)
 
@@ -1222,6 +1223,9 @@ class Resource(object):
             
             try:
                 curl.setopt(pycurl.URL, uri(self.uri, path, **params).encode('utf-8'))
+                params = urlparse(self.uri)
+                if params.username and params.password:
+                    curl.setopt(pycurl.USERPWD, "%s:%s" % (params.username, params.password))
                 curl.setopt(pycurl.WRITEFUNCTION, stringbuf.write)
                 curl.setopt(pycurl.FOLLOWLOCATION, 1)
                 curl.setopt(pycurl.MAXREDIRS, 5)
